@@ -16,9 +16,10 @@ int NewTunnel(cJSON	*json);
 int InitTunnelList();
 int SetLocalAddrInfo(char *url,char *ReqId,int istunnel);
 int RemoteSslInit(Sockinfo *tempinfo);
-int LocalToRemote(Sockinfo *tempinfo,ssl_info *sslinfo);
-int RemoteToLocal(ssl_info *sslinfo,Sockinfo *tempinfo);
-int ConnectLocal(ssl_info *sslinfo,Sockinfo *tempinfo);
+int LocalSslInit(Sockinfo *tempinfo);
+int LocalToRemote(Sockinfo *tempinfo);
+int RemoteToLocal(Sockinfo *tempinfo);
+int ConnectLocal(Sockinfo *tempinfo);
 int CmdSock(int *mainsock,Sockinfo *tempinfo,struct sockaddr_in server_addr);
 int ConnectMain(int *mainsock,struct sockaddr_in server_addr,ssl_info **mainsslinfo);
 #endif
